# MYP Druckerverwaltung - Installationskorrekturen

## Problembehebung der Raspberry Pi Installation

### Datum: 31.05.2025
### Status: Behoben ✅

## Identifizierte Probleme

### 1. Chromium-Browser Paketname
- **Problem**: `chromium-browser` Paket nicht verfügbar
- **Ursache**: Paketname variiert zwischen Distributionen
- **Lösung**: Dynamische Erkennung verschiedener Chromium-Paketnamen

### 2. useradd Command not found
- **Problem**: `useradd` Befehl nicht gefunden
- **Ursache**: PATH-Variable nicht korrekt gesetzt
- **Lösung**: Explizites Setzen der PATH-Variable für System-Tools

### 3. Fehlende Fehlerbehandlung
- **Problem**: Installation bricht bei ersten Fehlern ab
- **Ursache**: Unzureichende Fehlerbehandlung
- **Lösung**: Robuste Fallback-Mechanismen implementiert

## Implementierte Verbesserungen

### 📦 Paket-Installation
```bash
# Vor der Korrektur
apt-get install -y chromium-browser

# Nach der Korrektur
if apt-get install -y chromium 2>/dev/null; then
    log "✅ Chromium erfolgreich installiert"
elif apt-get install -y chromium-browser 2>/dev/null; then
    log "✅ Chromium-Browser erfolgreich installiert"
else
    warning "⚠️  Chromium konnte nicht automatisch installiert werden"
fi
```

### 👤 Benutzer-Erstellung
```bash
# Vor der Korrektur
useradd -m -s /bin/bash "$APP_USER"

# Nach der Korrektur
if ! useradd -m -s /bin/bash "$APP_USER" 2>/dev/null; then
    warning "Fehler bei useradd - versuche adduser..."
    if ! adduser --disabled-password --gecos "" "$APP_USER" 2>/dev/null; then
        error "Konnte Benutzer '$APP_USER' nicht erstellen. System-Tools prüfen."
    fi
fi
```

### 🔧 Chromium-Binary Erkennung
```bash
# Dynamische Erkennung des Chromium-Pfads
CHROMIUM_BIN=""
for chromium_path in "/usr/bin/chromium" "/usr/bin/chromium-browser" "/snap/bin/chromium"; do
    if [ -x "$chromium_path" ]; then
        CHROMIUM_BIN="$chromium_path"
        log "Chromium gefunden: $CHROMIUM_BIN"
        break
    fi
done
```

### 🔍 System-Tools Validierung
```bash
# Prüfe kritische Befehle vor Verwendung
for cmd in useradd usermod systemctl apt-get; do
    if ! command -v "$cmd" &> /dev/null; then
        error "Erforderlicher Befehl '$cmd' nicht gefunden. PATH: $PATH"
    fi
done
```

## Neue Wartungstools

### 🔧 myp-repair
Automatisches Reparatur-Tool für häufige Probleme:
- Prüft und repariert Services
- Erstellt fehlende Benutzer nach
- Installiert fehlende Pakete
- Korrigiert Berechtigungen

```bash
sudo myp-repair
```

### 🔍 myp-maintenance diagnose
Umfassendes Diagnose-Tool:
- System-Informationen
- Service-Status
- Port-Belegung
- Benutzer-Konfiguration
- Letzte Logs

```bash
myp-maintenance diagnose
```

## Getestete Umgebungen

- ✅ Debian 12 (Bookworm)
- ✅ Ubuntu 22.04 LTS
- ✅ Raspberry Pi OS (64-bit)
- ✅ Systeme mit/ohne vorinstalliertem Chromium

## Backup und Wiederherstellung

### Automatische Backups
- Täglich um 2:00 Uhr
- 30 Tage Aufbewahrung
- Komprimierte Datenbank und Konfiguration

### Notfall-Wiederherstellung
```bash
# Im Schnellstart-Skript verfügbar
sudo myp-notfall-reset
```

## Sicherheitsverbesserungen

1. **Berechtigungen**: Strikte Benutzer-/Gruppentrennung
2. **Firewall**: Automatische UFW-Konfiguration
3. **Services**: Isolation und Überwachung
4. **Backups**: Automatische Datensicherung

## Installation ausführen

```bash
# Vollständige Installation
sudo ./schnellstart_raspberry_pi.sh

# Bei Problemen: Reparatur
sudo myp-repair

# Status prüfen
myp-maintenance status
myp-maintenance diagnose
```

## Troubleshooting

### Problem: Services starten nicht
```bash
sudo myp-repair
sudo myp-maintenance restart
```

### Problem: Kiosk-Modus funktioniert nicht
```bash
# Chromium prüfen
myp-maintenance diagnose

# Kiosk neu starten
myp-maintenance kiosk-restart
```

### Problem: Benutzer fehlen
```bash
sudo myp-repair
```

## Kontakt

Bei anhaltenden Problemen:
1. Diagnose ausführen: `myp-maintenance diagnose`
2. Logs sammeln: `myp-maintenance logs`
3. Reparatur versuchen: `sudo myp-repair`

---
**Dokumentation erstellt**: 31.05.2025  
**Letzte Aktualisierung**: 31.05.2025  
**Version**: 2.0.0 